<?php

declare(strict_types=1);

namespace Drupal\joinup_group\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Field\EntityReferenceFieldItemList;

/**
 * Interface for entities that are group content.
 *
 * The following group types can be returned for these bundles:
 * - collections: community content, custom pages, and solutions.
 * - solutions: asset releases and asset distributions.
 */
interface GroupContentInterface extends ContentEntityInterface {

  /**
   * Returns whether or not the entity is associated with a group.
   *
   * @return bool
   *   TRUE if the entity is associated with a group.
   */
  public function hasGroup(): bool;

  /**
   * Returns the group to which this entity belongs.
   *
   * @return \Drupal\joinup_group\Entity\GroupInterface
   *   The parent group.
   *
   * @throws \Drupal\joinup_group\Exception\MissingGroupException
   *   Thrown when the parent group is missing.
   */
  public function getGroup(): GroupInterface;

  /**
   * Returns the ID of the group to which this entity belongs.
   *
   * @return string
   *   The parent group ID.
   *
   * @throws \Drupal\joinup_group\Exception\MissingGroupException
   *   Thrown when the parent group is missing.
   */
  public function getGroupId(): string;

  /**
   * Returns the "shared in" field item list.
   *
   * @return \Drupal\Core\Field\EntityReferenceFieldItemList|null
   *   The "shared in" field item list or NULL if it doesn't exist.
   */
  public function getSharedInField(): ?EntityReferenceFieldItemList;

}
